@@ -27,8 +27,8 @@ import (
 	"github.com/superfly/flyctl/internal/filemu"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/prompt"
-	"github.com/superfly/flyctl/internal/sourcecode"
 	"github.com/superfly/flyctl/iostreams"
+	"github.com/superfly/flyctl/scanner"
 )
 
 func newLaunch() (cmd *cobra.Command) {
@@ -150,7 +150,7 @@ func run(ctx context.Context) (err error) {
 
 	appConfig.SetPrimaryRegion(regionCode)
 
-	var srcInfo *sourcecode.SourceInfo
+	var srcInfo *scanner.SourceInfo
 
 	// Determine whether to deploy from an image
 	if img := flag.GetString(ctx, "image"); img != "" {
@@ -233,13 +233,13 @@ func run(ctx context.Context) (err error) {
 	return
 }
 
-func scanAndConfigure(ctx context.Context, dir string, appConfig *app.Config) (srcInfo *sourcecode.SourceInfo, err error) {
+func scanAndConfigure(ctx context.Context, dir string, appConfig *app.Config) (srcInfo *scanner.SourceInfo, err error) {
 
 	io := iostreams.FromContext(ctx)
 
-	srcInfo = new(sourcecode.SourceInfo)
+	srcInfo = new(scanner.SourceInfo)
 
-	scannedDirInfo, err := sourcecode.Scan(dir)
+	scannedDirInfo, err := scanner.Scan(dir)
 
 	if err != nil {
 		return srcInfo, err
@@ -279,7 +279,7 @@ func scanAndConfigure(ctx context.Context, dir string, appConfig *app.Config) (s
 	return
 }
 
-func setScannerPrefs(ctx context.Context, appConfig *app.Config, srcInfo *sourcecode.SourceInfo) (err error) {
+func setScannerPrefs(ctx context.Context, appConfig *app.Config, srcInfo *scanner.SourceInfo) (err error) {
 
 	client := client.FromContext(ctx).API()
 
@@ -425,7 +425,7 @@ func setScannerPrefs(ctx context.Context, appConfig *app.Config, srcInfo *source
 	return
 }
 
-func installFiles(ctx context.Context, dir string, srcInfo *sourcecode.SourceInfo) (err error) {
+func installFiles(ctx context.Context, dir string, srcInfo *scanner.SourceInfo) (err error) {
 	for _, f := range srcInfo.Files {
 		path := filepath.Join(dir, f.Path)
 
@@ -456,7 +456,7 @@ func installFiles(ctx context.Context, dir string, srcInfo *sourcecode.SourceInf
 	return
 }
 
-func printAppType(ctx context.Context, srcInfo *sourcecode.SourceInfo) {
+func printAppType(ctx context.Context, srcInfo *scanner.SourceInfo) {
 	io := iostreams.FromContext(ctx)
 
 	var article string = "a"
@@ -493,7 +493,7 @@ func setupHttpService(ctx context.Context, appConfig *app.Config) (err error) {
 	return
 }
 
-func execInitCommand(ctx context.Context, command sourcecode.InitCommand) (err error) {
+func execInitCommand(ctx context.Context, command scanner.InitCommand) (err error) {
 	binary, err := exec.LookPath(command.Command)
 	if err != nil {
 		return fmt.Errorf("%s not found in $PATH - make sure app dependencies are installed and try again", command.Command)
