@@ -35,6 +35,7 @@ import (
 	"github.com/superfly/flyctl/internal/command/releases"
 	"github.com/superfly/flyctl/internal/command/restart"
 	"github.com/superfly/flyctl/internal/command/resume"
+	"github.com/superfly/flyctl/internal/command/secrets"
 	"github.com/superfly/flyctl/internal/command/services"
 	"github.com/superfly/flyctl/internal/command/status"
 	"github.com/superfly/flyctl/internal/command/suspend"
@@ -144,6 +145,7 @@ func New() *cobra.Command {
 		machine.New(),
 		monitor.New(),
 		ips.New(),
+		secrets.New(),
 	}
 
 	if os.Getenv("DEV") != "" {
